Stream thread-safe checkpoint.

Moving data structures to critical / protected section.
这个提交包含在:
Ben Sander
2016-03-28 09:46:40 -05:00
父节点 3aed9d3b19
当前提交 3f18bab2c7
修改 5 个文件,包含 171 行新增129 行删除
+3 -3
查看文件
@@ -82,7 +82,7 @@ hipError_t hipStreamWaitEvent(hipStream_t stream, hipEvent_t event, unsigned int
// TODO-hcc Convert to use create_blocking_marker(...) functionality.
// Currently we have a super-conservative version of this - block on host, and drain the queue.
// This should create a barrier packet in the target queue.
stream->wait();
stream->locked_wait();
e = hipSuccess;
}
@@ -101,7 +101,7 @@ hipError_t hipStreamSynchronize(hipStream_t stream)
ihipDevice_t *device = ihipGetTlsDefaultDevice();
device->locked_syncDefaultStream(true/*waitOnSelf*/);
} else {
stream->wait();
stream->locked_wait();
e = hipSuccess;
}
@@ -125,7 +125,7 @@ hipError_t hipStreamDestroy(hipStream_t stream)
ihipDevice_t *device = ihipGetTlsDefaultDevice();
device->locked_syncDefaultStream(true/*waitOnSelf*/);
} else {
stream->wait();
stream->locked_wait();
e = hipSuccess;
}